| Title: | Simple Example of Using 'tl' for Logging |
|---|---|
| Description: | An illustraton of how the 'tl' package permits consistent logging from both R and C++ in a manner that is 'tiny, fast, capable'. |
| Authors: | Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>) |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-07-02 16:44:41 UTC |
| Source: | https://github.com/eddelbuettel/tlexample |
An illustraton of how the 'tl' package permits consistent logging from both R and C++ in a manner that is 'tiny, fast, capable'.
Index of help topics:
bar Simple example function foo Simple Example of tl() use tlexample-package Simple Example of Using 'tl' for Logging
Dirk Eddelbuettel <[email protected]>
Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>)
The tl package provides a uniform interface to logging
from both R and C++ using the same namespaced tl::debug() (and alike
for differ logging verbs) interface. This package (and function)
demonstrates it.
bar(s = "baz")bar(s = "baz")
s |
A character string, defaults to “baz” |
Nothing is returned as the function is invoked for its side-effect.
This function details how one can combine logging from R (by
calling functions such as tl::debug()) with C++ logging, here from a
function bar() in this package.
foo()foo()
foo()foo()