Package 'tlexample'

Title: Concise Summary of What the Package Does
Description: More about what it does (maybe more than one line).
Authors: Dirk Eddelbuettel [aut, cre]
Maintainer: Dirk Eddelbuettel <[email protected]>
License: GPL (>= 2)
Version: 0.0.1
Built: 2026-06-04 11:13:35 UTC
Source: https://github.com/eddelbuettel/tlexample

Help Index


Concise Summary of What the Package Does

Description

More about what it does (maybe more than one line).

Package Content

Index of help topics:

bar                     Simple example function
tlexample-package       Concise Summary of What the Package Does

Maintainer

Dirk Eddelbuettel <[email protected]>

Author(s)

Dirk Eddelbuettel [aut, cre]


Simple example function

Description

The tl package provides a uniform interface to logging from both R and C++ using the same namespaced tl::debug() (and alike for differ logging verbs) interface. This package (and function) demonstrates it.

Usage

bar(s = "baz")

Arguments

s

A character string, defaults to “baz”

Value

Nothing is returned as the function is invoked for its side-effect.