| Title: | Concise Summary of What the Package Does |
|---|---|
| Description: | More about what it does (maybe more than one line). |
| Authors: | Dirk Eddelbuettel [aut, cre] |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-06-04 11:13:35 UTC |
| Source: | https://github.com/eddelbuettel/tlexample |
More about what it does (maybe more than one line).
Index of help topics:
bar Simple example function tlexample-package Concise Summary of What the Package Does
Dirk Eddelbuettel <[email protected]>
Dirk Eddelbuettel [aut, cre]
The tl package provides a uniform interface to logging
from both R and C++ using the same namespaced tl::debug() (and alike
for differ logging verbs) interface. This package (and function)
demonstrates it.
bar(s = "baz")bar(s = "baz")
s |
A character string, defaults to “baz” |
Nothing is returned as the function is invoked for its side-effect.